@@ -4,7 +4,7 @@ use warnings;
 use Hook::AfterRuntime;
 
 sub import {
-    after_runtime { $main::TRIGGERED++ } caller;
+    after_runtime { $main::TRIGGERED++ };
 }
 
 1;
